* ver: 1.3.19 scaler
* ver: 1.3.18 normalize data
* ver: 1.3.17 ./ 
* ver: 1.3.16 ./
* ver: 1.3.15 /docs
* ver: 1.3.14 del datafile for subdir
* ver: 1.3.13 modify index
* ver: 1.3.12 index.md modify
* ver: 1.3.11 add datafiles
* ver: 1.3.10 add normalization dataset minmax and meanstd
* ver: 1.3.9  just add chang log modify long description